@@ -29,7 +29,6 @@
 
 // svncpp
 #include "svncpp/client.hpp"
-// #include "svncpp/m_check.hpp"
 
 // app
 #include "action.hpp"
@@ -41,45 +40,6 @@
 // subversion api
 #include "svn_wc.h"
 
-//TODO: This isn't actually used, and an exact copy lives in listener.cpp which is used
-// I suspect we should get rid of one, but I'm not sure which at the  moment...
-// static const wxChar *
-// ACTION_NAMES [] =
-// {
-//   _("Add"),              // svn_wc_notify_add,
-//   _("Copy"),             // svn_wc_notify_copy,
-//   _("Delete"),           // svn_wc_notify_delete,
-//   _("Restore"),          // svn_wc_notify_restore,
-//   _("Revert"),           // svn_wc_notify_revert,
-//   NULL ,                 // NOT USED HERE svn_wc_notify_failed_revert,
-//   _("Resolved"),         // svn_wc_notify_resolved,
-//   _("Skip"),             // NOT USED HERE svn_wc_notify_skip,
-//   _("Deleted"),          // svn_wc_notify_update_delete,
-//   _("Added"),            // svn_wc_notify_update_add,
-//   _("Updated"),          // svn_wc_notify_update_update,
-//   NULL,                  // NOT USED HERE svn_wc_notify_update_completed,
-//   NULL,                  // NOT USED HERE svn_wc_notify_update_external,
-//   NULL,                  // NOT USED HERE svn_wc_notify_status_completed
-//   NULL,                  // NOT USED HERE svn_wc_notify_status_external#include "svncpp/m_check.hpp"
-
-//   _("Modified"),         // svn_wc_notify_commit_modified,
-//   _("Added"),            // svn_wc_notify_commit_added,
-//   _("Deleted"),          // svn_wc_notify_commit_deleted,
-//   _("Replaced"),         // svn_wc_notify_commit_replaced,
-//   NULL,                  // NOT USED HERE svn_wc_notify_commit_postfix_txdelta
-//   NULL,                  // NOT USED HERE svn_wc_notify_blame_revision
-//   _("Locked"),           // svn_wc_notify_locked
-//   _("Unlocked"),         // svn_wc_notify_unlocked
-//   _("Failed to lock"),   // svn_wc_notify_failed_lock
-//   _("Failed to unlock")  // svn_wc_notify_failed_unlock
-// };
-
-// #if CHECK_SVN_SUPPORTS_LOCK
-// const int MAX_ACTION = svn_wc_notify_failed_unlock;
-// #else
-// const int MAX_ACTION = svn_wc_notify_commit_postfix_txdelta;
-// #endif
-
 #ifdef USE_SIMPLE_WORKER
 void
 SafeYield ()
@@ -151,7 +111,6 @@ public:
 
 };
 
-
 const unsigned int Action::DONT_UPDATE          = 0x0001;
 const unsigned int Action::UPDATE_LATER         = 0x0002;
 const unsigned int Action::WITHOUT_TARGET       = 0x0004;
@@ -178,32 +137,6 @@ Action::~Action ()
   delete m;
 }
 
-void
-Action::PostStringEvent (int code, wxString str, int event_id)
-{
-  wxCommandEvent event (wxEVT_COMMAND_MENU_SELECTED, event_id);
-  event.SetInt (code);
-  event.SetString (str);
-
-  // send in a thread-safe way
-  wxPostEvent (m->parent, event);
-
-  SafeYield ();
-}
-
-void
-Action::PostDataEvent (int code, void *data, int event_id)
-{
-  wxCommandEvent event (wxEVT_COMMAND_MENU_SELECTED, event_id);
-  event.SetInt (code);
-  event.SetClientData (data);
-
-  // send in a thread-safe way
-  wxPostEvent (m->parent, event);
-
-  SafeYield ();
-}
-
 void
 Action::SetTracer (Tracer * t, bool own)
 {
@@ -237,7 +170,12 @@ Action::Trace (const wxString & msg)
 void
 Action::TraceError (const wxString & msg)
 {
-  Trace (msg);
+  if (m->tracer)
+  {
+    m->tracer->TraceError (msg);
+  }
+
+  SafeYield ();
 }
 
 void
@@ -338,27 +276,12 @@ Action::SetName (const wxString & name)
   m->name = name;
 }
 
-void
-Action::PostEvent (wxEvent & event)
-{
-  wxEvtHandler * handler;
-
-  handler = GetParent ();
-
-  if (handler == 0)
-    return;
-
-  wxPostEvent (handler, event);
-}
-
-
 unsigned int
 Action::GetFlags () const
 {
   return m->flags;
 }
 
-
 void
 Action::SetFlags (unsigned int flags)
 {
