@@ -35,6 +35,7 @@
 #include "svncpp/url.hpp"
 
 // app
+#include "action_event.hpp"
 #include "diff_action.hpp"
 #include "diff_data.hpp"
 #include "diff_dlg.hpp"
@@ -42,43 +43,38 @@
 #include "preferences.hpp"
 #include "utils.hpp"
 
-
 struct DiffAction::Data 
 {
 private:
-  Action * mAction;
+  Action * action;
 
 public:
   bool showDialog;
   DiffData diffData;
+  wxWindow * parent;
 
-
-  Data (Action * action)
-    : mAction (action), showDialog (true)
+  Data (Action * action_, wxWindow * parent_)
+    : action (action_), showDialog (true), parent (parent_)
   {
   }
 
-
-  Data (Action * action, DiffData & data)
-    : mAction (action), showDialog (false), diffData (data)
+  Data (Action * action_, wxWindow * parent_, DiffData & data)
+    : action (action_), showDialog (false), diffData (data), parent (parent_)
   {
   }
 
-
   svn::Context * 
   GetContext ()
   {
-    return mAction->GetContext ();
+    return action->GetContext ();
   }
 
-
   void
   Trace (const wxString & msg)
   {
-    mAction->Trace (msg);
+    action->Trace (msg);
   }
 
-
   /**
    * retrieves the status information for a file
    */
@@ -91,7 +87,6 @@ public:
     return status;
   }
 
-
   /**
    * retrieves the revision information for a file
    */
@@ -102,7 +97,6 @@ public:
     return entry.revision ();
   }
 
-
   /**
    * retrieves the effective path for the first file
    */
@@ -114,7 +108,6 @@ public:
     return path;
   }
 
-
   /**
    * retrieves the effective path for the second file
    */
@@ -127,7 +120,6 @@ public:
       return path;
   }
 
-
   /** 
    * Check the status of a file. Only regular
    * versioned files will pass this check
@@ -144,7 +136,6 @@ public:
     return true;
   }
 
-
   /**
    * performs the diff operation on a single path:
    *
@@ -173,30 +164,29 @@ public:
       return;
     }
 
-
     switch (diffData.compareType)
     {
     case DiffData::WITH_BASE:
       dstFile1 = path;
-      dstFile2 = mAction->GetPathAsTempFile (getPath1 (path), svn::Revision::BASE);
+      dstFile2 = action->GetPathAsTempFile (getPath1 (path), svn::Revision::BASE);
 
       break;
 
     case DiffData::WITH_HEAD:
       dstFile1 = path;
-      dstFile2 = mAction->GetPathAsTempFile (getPath1 (path), svn::Revision::HEAD);
+      dstFile2 = action->GetPathAsTempFile (getPath1 (path), svn::Revision::HEAD);
 
       break;
 
     case DiffData::WITH_DIFFERENT_REVISION:
       dstFile1 = path;
-      dstFile2 = mAction->GetPathAsTempFile (getPath1 (path), diffData.revision1);
+      dstFile2 = action->GetPathAsTempFile (getPath1 (path), diffData.revision1);
 
       break;
 
     case DiffData::TWO_REVISIONS:
-      dstFile1 = mAction->GetPathAsTempFile (getPath1 (path), diffData.revision1);
-      dstFile2 = mAction->GetPathAsTempFile (getPath2 (path), diffData.revision2);
+      dstFile1 = action->GetPathAsTempFile (getPath1 (path), diffData.revision1);
+      dstFile2 = action->GetPathAsTempFile (getPath2 (path), diffData.revision2);
 
       break;
 
@@ -227,31 +217,28 @@ public:
     wxString msg;
     msg.Printf (_("Execute diff tool: %s"), cmd.c_str ());
     Trace (msg);
-    wxExecute (cmd);
+
+    ActionEvent::Post (parent, TOKEN_CMD_DIFF, cmd);
   }
 };
 
-
 DiffAction::DiffAction (wxWindow * parent)
   : Action (parent, _("Diff"), GetBaseFlags ())
 {
-  m = new Data (this);
+  m = new Data (this, parent);
 }
 
-
 DiffAction::DiffAction (wxWindow * parent, DiffData & data)
   : Action (parent, _("Diff"), GetBaseFlags ())
 {
-  m = new Data (this, data);
+  m = new Data (this, parent, data);
 }
 
-
 DiffAction::~DiffAction ()
 {
   delete m;
 }
 
-
 bool
 DiffAction::Prepare ()
 {
@@ -275,7 +262,8 @@ DiffAction::Prepare ()
 
     if (isRemote)
     {
-      DiffData::CompareType types [] = {
+      DiffData::CompareType types [] =
+      {
         DiffData::TWO_REVISIONS
       };
 
@@ -291,7 +279,6 @@ DiffAction::Prepare ()
   return true;
 }
 
-
 bool
 DiffAction::Perform ()
 {
@@ -305,6 +292,7 @@ DiffAction::Perform ()
  
   return true;
 }
+
 /* -----------------------------------------------------------------
  * local variables:
  * eval: (load-file "../rapidsvn-dev.el")
