@@ -33,7 +33,6 @@
 #include "diff_dlg.hpp"
 #include "utils.hpp"
 
-
 /** event IDs for the controls used in this file */
 enum
 {
@@ -50,16 +49,13 @@ enum
   ID_RevisionTwo
 };
 
-
 /* custom event to forward necessary updates */
 BEGIN_DECLARE_EVENT_TYPES()
     DECLARE_EVENT_TYPE(wxEVENT_UPDATE, wxEVT_USER_FIRST)
 END_DECLARE_EVENT_TYPES()
 
-
 DEFINE_EVENT_TYPE(wxEVENT_UPDATE)
 
-
 #define EVENT_UPDATE(id, fn) \
     DECLARE_EVENT_TABLE_ENTRY( \
         wxEVENT_UPDATE, id, -1, \
@@ -67,7 +63,6 @@ DEFINE_EVENT_TYPE(wxEVENT_UPDATE)
         (wxObject *) NULL \
     ),
 
-
 /**
  * Panel that lets the user select either a revision or a date and
  * optionally another URL (if she doesnt want to compare against
@@ -87,7 +82,6 @@ public:
     CheckControls ();
   }
 
-
   /**
    * Checks the controls for validity and
    * enables/disables controls as result of this check
@@ -100,7 +94,6 @@ public:
     CheckUrlCtrls ();
   }
 
-
   /**
    * returns whether the controls contain valid entries
    *
@@ -126,7 +119,6 @@ public:
     return valid;
   }
 
-
   const svn::Revision
   GetRevision () const
   {
@@ -151,21 +143,18 @@ public:
     }
   }
 
-
   bool
   GetUseUrl () const
   {
     return mCheckUseUrl->GetValue ();
   }
 
-
   const wxString
   GetUrl () const
   {
     return mTextUrl->GetValue ();
   }
 
-
   void
   SetRevision (const svn::Revision & revision)
   {
@@ -198,28 +187,24 @@ public:
     }
   }
 
-
   void
   SetUseUrl (bool value)
   {
     mCheckUseUrl->SetValue (value);
   }
 
-
   void
   SetUrl (const wxString & url)
   {
     mTextUrl->SetValue (url);
   }
 
-
   void
   EnableUrl (bool enable)
   {
     // @todo
   }
 
-
 private:
   bool mEnableUrl;
 
@@ -250,7 +235,6 @@ private:
   /** browse button if the user wants to search for a local file */
   wxButton * mButtonBrowse;
 
-
   /** Initialize and position the controls for the panel */
   void
   InitControls (const wxString & title)
@@ -275,8 +259,7 @@ private:
     gridSizer->Add (0,0);
 
     // second row: date
-    mRadioUseDate = new wxRadioButton (
-      this, ID_UseDate, _("Date:"));
+    mRadioUseDate = new wxRadioButton (this, ID_UseDate, _("Date:"));
     mTextDate = new wxTextCtrl (this, ID_Date, wxEmptyString);
 
     gridSizer->Add (mRadioUseDate);
@@ -306,7 +289,6 @@ private:
     mainSizer->Fit (this);
   }
 
-
   /** checks the revision controls for validity */
   void
   CheckRevisionCtrls ()
@@ -323,7 +305,6 @@ private:
     mTextRevision->Enable (!mCheckUseLatest->GetValue ());
   }
 
-
   /** checks the date control for validity */
   void
   CheckDateCtrls ()
@@ -331,7 +312,6 @@ private:
     mTextDate->Enable (mRadioUseDate->GetValue ());
   }
 
-
   /** checks the url controls for validity */
   void
   CheckUrlCtrls ()
@@ -347,7 +327,6 @@ private:
     mButtonBrowse->Enable (mEnableUrl);
   }
 
-
   /**
    * If anything has changed in the form,
    * e.g. a text has been entered, a radio button
@@ -361,17 +340,12 @@ private:
   OnCommand (wxCommandEvent & event)
   {
     CheckControls ();
-
-    wxCommandEvent updateEvent (wxEVENT_UPDATE);
-    wxPostEvent (GetParent (), updateEvent);
   }
 
-
 private:
   DECLARE_EVENT_TABLE ()
 };
 
-
 BEGIN_EVENT_TABLE (RevisionPanel, wxPanel)
   EVT_CHECKBOX (ID_UseUrl, RevisionPanel::OnCommand)
   EVT_CHECKBOX (ID_UseLatest, RevisionPanel::OnCommand)
@@ -381,7 +355,6 @@ BEGIN_EVENT_TABLE (RevisionPanel, wxPanel)
   EVT_TEXT (ID_Date, RevisionPanel::OnCommand)
 END_EVENT_TABLE ()
 
-
 enum
 {
   COMPARE_WITH_BASE = 0,
@@ -391,12 +364,13 @@ enum
   COMPARE_COUNT
 };
 
-
-static const DiffData::CompareType COMPARE_TYPES [] = {
+static const DiffData::CompareType COMPARE_TYPES [] =
+{
   DiffData::WITH_BASE,
   DiffData::WITH_HEAD,
   DiffData::WITH_DIFFERENT_REVISION,
-  DiffData::TWO_REVISIONS};
+  DiffData::TWO_REVISIONS
+};
 
 /**
  * This panel contains all the controls relevant for
@@ -411,10 +385,9 @@ public:
   RevisionPanel * mRevisionTwo;
   wxString mCompareTypeLabels [COMPARE_COUNT];
 
-
   /** Constructor */
   Data (wxWindow * parent)
-    : wxPanel (parent), mParent (parent)
+    : wxPanel (parent), mParent (parent), mCompareType (-1)
   {
     mCompareTypeLabels [COMPARE_WITH_BASE] = _("Diff to BASE");
     mCompareTypeLabels [COMPARE_WITH_HEAD] = _("Diff to HEAD");
@@ -427,7 +400,6 @@ public:
     CheckControls ();
   }
 
-
   const DiffData
   GetDiffData () const
   {
@@ -453,7 +425,6 @@ public:
     return diffData;
   }
 
-
   void
   SetData (const DiffData & diffData)
   {
@@ -463,7 +434,6 @@ public:
     SetCompareType (diffData.compareType);
   }
 
-
   void
   EnableUrl (bool value)
   {
@@ -471,7 +441,6 @@ public:
     mRevisionTwo->EnableUrl (value);
   }
 
-
   void
   AllowCompareTypes (const DiffData::CompareType types [],
                      size_t count)
@@ -497,7 +466,6 @@ public:
     SetCompareType (oldCompareType);
   }
 
-
   void
   AllowCompareTypes ()
   {
@@ -515,10 +483,10 @@ public:
     SetCompareType (oldCompareType);
   }
 
-
 private:
   wxWindow * mParent;
   wxButton * mButtonOK;
+  int mCompareType;
 
   void
   InitControls ()
@@ -570,9 +538,13 @@ private:
     mainSizer->SetSizeHints (this);
     mainSizer->Fit (this);
 
-    AllowCompareTypes ();
-  }
+    mButtonOK->SetDefault ();
 
+    AllowCompareTypes ();
+    // call this after AllowCompareTypes (), because ComboCmpType is not initialized yet.
+    // Set CompareType to BASE by default.
+    mCompareType = 0;
+  }
 
   void
   CheckControls ()
@@ -607,7 +579,6 @@ private:
     mButtonOK->Enable (IsValid ());
   }
 
-
   bool
   IsValid () const
   {
@@ -622,7 +593,6 @@ private:
     return valid;
   }
 
-
   /**
    * Add a compare type to the combo box
    */
@@ -640,7 +610,6 @@ private:
     }
   }
 
-
   /**
    * Get selected @a CompareType
    *
@@ -650,19 +619,18 @@ private:
   DiffData::CompareType
   GetCompareType () const
   {
-    int sel = mComboCmpType->GetSelection ();
-
-    if (sel < 0)
+    if (mCompareType < 0)
       return DiffData::INVALID_COMPARE_TYPE;
 
-    DiffData::CompareType* ct = (DiffData::CompareType*) mComboCmpType->GetClientData (sel);
+    DiffData::CompareType* ct =
+      (DiffData::CompareType*) mComboCmpType->GetClientData (mCompareType);
+
     if (!ct)
       return DiffData::INVALID_COMPARE_TYPE;
 
     return *ct;
   }
 
-
   /**
    * Select @a CompareType in the combo-box.
    * If not found, select first entry in the combo-box
@@ -696,26 +664,23 @@ private:
     return found;
   }
 
-
   void
   OnCommand (wxCommandEvent & event)
   {
+    mCompareType = event.GetInt();
     CheckControls ();
   }
 
-
 private:
   DECLARE_EVENT_TABLE ()
 };
 
 
-
 BEGIN_EVENT_TABLE (DiffDlg::Data, wxPanel)
   EVT_COMBOBOX (ID_CompareType, Data::OnCommand)
   EVENT_UPDATE (-1, Data::OnCommand)
 END_EVENT_TABLE ()
 
-
 DiffDlg::DiffDlg (wxWindow * parent)
   : wxDialog (parent, -1, _("Diff"), wxDefaultPosition,
               wxDefaultSize, wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER)
@@ -735,33 +700,28 @@ DiffDlg::DiffDlg (wxWindow * parent)
   CentreOnParent();
 }
 
-
 DiffDlg::~DiffDlg ()
 {
 }
 
-
 const DiffData
 DiffDlg::GetData () const
 {
   return m->GetDiffData ();
 }
 
-
 void
 DiffDlg::SetData (const DiffData & diffData)
 {
   m->SetData (diffData);
 }
 
-
 void
 DiffDlg::EnableUrl (bool value)
 {
   m->EnableUrl (value);
 }
 
-
 void
 DiffDlg::AllowCompareTypes (const DiffData::CompareType types [],
                             size_t count)
@@ -769,14 +729,12 @@ DiffDlg::AllowCompareTypes (const DiffData::CompareType types [],
   m->AllowCompareTypes (types, count);
 }
 
-
 void
 DiffDlg::AllowCompareTypes ()
 {
   m->AllowCompareTypes ();
 }
 
-
 /* -----------------------------------------------------------------
  * local variables:
  * eval: (load-file "../rapidsvn-dev.el")
