@@ -79,14 +79,12 @@ enum
 
 static const unsigned int MAXLENGTH_BOOKMARK = 35;
 
-
 const static wxChar ConfigBookmarkFmt [] = wxT("/Bookmarks/Bookmark%ld");
 const static wxChar ConfigBookmarkCount [] = wxT("/Bookmarks/Count");
 const static wxChar ConfigFlatModeFmt [] = wxT("/Bookmarks/Bookmark%ldFlat");
 
 static const wxString EmptyString;
 
-
 // local functions
 static bool
 IsValidSeparator (const wxString & sep)
@@ -94,7 +92,6 @@ IsValidSeparator (const wxString & sep)
   return ((sep == wxT("/")) || (sep == wxT("\\")));
 }
 
-
 /** 
  * data structure that contains information about
  * a single bookmark
@@ -105,19 +102,16 @@ public:
   svn::Context * context;
   bool flatMode;
 
-
   Bookmark (bool flatMode_=false)
     : context (0), flatMode (flatMode_)
   {
   }
 
-
   ~Bookmark ()
   {
     ClearContext ();
   }
 
-
   void
   ClearContext ()
   {
@@ -128,20 +122,16 @@ public:
     }
   }
 
-
   void
   SetAuthCache (bool value)
   {
     if (context != 0)
       context->setAuthCache (value);
   }
-
 };
 
-
 static Bookmark InvalidBookmark;
 
-
 WX_DECLARE_STRING_HASH_MAP (Bookmark, BookmarkHashMap);
 
 struct FolderBrowser::Data
@@ -158,7 +148,6 @@ public:
   svn::Context defaultContext;
   bool useAuthCache;
 
-
   Data (wxWindow * window, const wxPoint & pos, const wxSize & size)
     : singleContext (0), window (window), listener (0), useAuthCache (true)
   {
@@ -181,7 +170,7 @@ public:
 
     FolderItemData* data = new FolderItemData (FOLDER_TYPE_BOOKMARKS);
     rootId = treeCtrl->AddRoot (_("Bookmarks"), FOLDER_IMAGE_COMPUTER,
-                                    FOLDER_IMAGE_COMPUTER, data);
+                                FOLDER_IMAGE_COMPUTER, data);
     treeCtrl->SetItemHasChildren (rootId, TRUE);
   }
 
@@ -200,6 +189,8 @@ public:
   AddBookmark (wxString name, bool flatMode)
   {
     TrimString (name);
+    if (name.Last () == '/')
+      name.RemoveLast ();
 
     svn::Path nameUtf8 (PathUtf8 (name));
     if (!nameUtf8.isUrl())
@@ -216,7 +207,6 @@ public:
       bookmarks [name].context = CreateContext ();
   }
 
-  
   /**
    * factory method to create a new context
    */
@@ -231,7 +221,6 @@ public:
     return context;
   }
 
-  
   const wxString
   GetPath ()
   {
@@ -281,8 +270,6 @@ public:
     return it->second.context;
   }
 
-
-
   void
   ShowMenu (wxPoint & pt)
   {
@@ -294,7 +281,7 @@ public:
 
     // create menu
     wxMenu menu;
-    int type =  data->getFolderType ();
+    int type = data->getFolderType ();
 
     AppendMenuItem (menu, ID_AddWcBookmark);
     AppendMenuItem (menu, ID_Checkout);
@@ -303,7 +290,7 @@ public:
     AppendMenuItem (menu, ID_CreateRepository);
     AppendMenuItem (menu, ID_Switch);
 
-    if (type==FOLDER_TYPE_BOOKMARK)
+    if (type == FOLDER_TYPE_BOOKMARK)
     {
       menu.AppendSeparator ();
       AppendMenuItem (menu, ID_EditBookmark);
@@ -335,7 +322,7 @@ public:
       item->Enable (enabled);
     }
 
-    if ((type==FOLDER_TYPE_BOOKMARK)||(type==FOLDER_TYPE_NORMAL))
+    if (type == FOLDER_TYPE_BOOKMARK || type == FOLDER_TYPE_NORMAL)
     {
       menu.AppendSeparator ();
       AppendMenuItem (menu, ID_Update);
@@ -350,7 +337,6 @@ public:
     window->PopupMenu (&menu, pt);
   }
 
-
   bool
   HasSubdirectories (const wxString & path)
   {
@@ -404,6 +390,20 @@ public:
     }
   }
 
+  void
+  OnTreeKeyDown (wxTreeEvent & event)
+  {
+    int code = event.GetKeyCode ();
+
+    if (treeCtrl->GetSelection ().IsOk () &&
+        !treeCtrl->IsExpanded (treeCtrl->GetSelection ()))
+    {
+      if (code == '-' || code == WXK_LEFT)
+        treeCtrl->Collapse (treeCtrl->GetItemParent (treeCtrl->GetSelection ()));
+    }
+    event.Skip ();
+  }
+
   void
   OnExpandItem (wxTreeEvent & event)
   {
@@ -423,7 +423,7 @@ public:
     FolderItemData* parentData = GetItemData (parentId);
     if(parentData)
     {
-        type = parentData->getFolderType ();
+      type = parentData->getFolderType ();
     }
 
     switch(type)
@@ -444,7 +444,7 @@ public:
                                                      data);
           treeCtrl->SetItemHasChildren (newId, TRUE);
           treeCtrl->SetItemImage (newId, FOLDER_IMAGE_BOOKMARK,
-                                    wxTreeItemIcon_Expanded);
+                                  wxTreeItemIcon_Expanded);
         }
       }
       break;
@@ -554,8 +554,7 @@ public:
         wxTreeItemId newId = treeCtrl->AppendItem(
           parentId, filename.GetFullName (), image, image, data);
 
-        treeCtrl->SetItemHasChildren (
-          newId, HasSubdirectories (path));
+        treeCtrl->SetItemHasChildren (newId, HasSubdirectories (path));
         treeCtrl->SetItemImage (newId, open_image, wxTreeItemIcon_Expanded);
       }
     }
@@ -578,9 +577,12 @@ public:
       svn::DirEntry entry = *it;
       int image = FOLDER_IMAGE_FOLDER;
       int open_image = FOLDER_IMAGE_OPEN_FOLDER;
+      int offset = 1;
 
-      wxString fullPath = Utf8ToLocal (entry.name ());
-      wxString filename (fullPath.Mid (parentPath.Length () + 1));
+      wxString fullPath = Utf8ToLocal (svn::Url::unescape (entry.name ()));
+      if (parentPath.Last () == '/')
+        offset = 0;
+      wxString filename (fullPath.Mid (parentPath.length () + offset));
       //parentHasSubdirectories = true;
 
       if (entry.kind () != svn_node_dir)
@@ -592,18 +594,14 @@ public:
                             filename, TRUE);
 
       wxTreeItemId newId =
-        treeCtrl->AppendItem(
-          parentId, filename,
-          image, image, data);
-      treeCtrl->SetItemHasChildren (
-        newId, true );
+        treeCtrl->AppendItem(parentId, filename,
+                             image, image, data);
+      treeCtrl->SetItemHasChildren (newId, true );
       treeCtrl->SetItemImage (newId, open_image,
-                                wxTreeItemIcon_Expanded);
-
+                              wxTreeItemIcon_Expanded);
     }
   }
 
-
   /**
    * Finds the child entry with @a path
    */
@@ -614,7 +612,7 @@ public:
     wxTreeItemId id = treeCtrl->GetFirstChild (parentId, cookie);
     wxTreeItemId childId;
 
-    while (id.IsOk ())
+    do
     {
       const FolderItemData * data = GetItemData (id);
 
@@ -624,7 +622,7 @@ public:
       if (!data->isReal ())
         break;
 
-      const svn::Path nodePath (LocalToUtf8(data->getPath ()));
+      const svn::Path nodePath (LocalToUtf8 (data->getPath ()));
       if (nodePath.length () == 0)
         break;
 
@@ -636,18 +634,18 @@ public:
       }
 
       // second check: match until path delimiter
-      wxString prefix (path.Left (nodePath.length ()));
-      wxString sep = path.Mid (nodePath.length (), 1);
+      wxString prefix (path.Left (Utf8ToLocal (nodePath.c_str()).length ()));
+      wxString sep (path.Mid (Utf8ToLocal (nodePath.c_str()).length (), 1));
 
       if (prefix.IsSameAs (Utf8ToLocal (nodePath.c_str ())) &&
-           IsValidSeparator (sep))
+          IsValidSeparator (sep))
       {
         childId = id;
         break;
       }
 
       id = treeCtrl->GetNextChild (parentId, cookie);
-    } // while (id.IsOk ())
+    } while (id.IsOk ());
 
     return childId;
   }
@@ -673,10 +671,6 @@ public:
       treeCtrl->SelectItem (treeCtrl->GetRootItem ());
       return true;
     }
-    
-    // Convert the input string to subversion internal representation
-    svn::Path pathPUtf8 (PathUtf8 (pathP));
-    const wxString path = Utf8ToLocal (pathPUtf8.c_str());
 
     wxTreeItemId bookmarkId = GetSelectedBookmarkId ();
 
@@ -685,9 +679,10 @@ public:
       return false;
 
     // begin searching in the folder hierarchy
-    bool success=false;
+    bool success = false;
     wxTreeItemId id = bookmarkId;
-    while (id.IsOk ())
+
+		do
     {
       const FolderItemData * data = GetItemData (id);
 
@@ -701,22 +696,24 @@ public:
         break;
 
       if (!data->isReal ())
-        break;
+			  break;
 
       const svn::Path nodePath (LocalToUtf8 (data->getPath ()));
       if (nodePath.length () == 0)
-        break;
+				break;
 
       // check if @a path and @a nodePath match already
       // in this case we are done
-      if (path.IsSameAs (Utf8ToLocal (nodePath.c_str())))
+      if (pathP.IsSameAs (Utf8ToLocal (nodePath.c_str())))
       {
         success = true;
         break;
+
       }
 
-      wxString prefix (path.Left (nodePath.length ()));
-      wxString sep (path.Mid (nodePath.length (), 1));
+      wxString prefix (pathP.Left (Utf8ToLocal (nodePath.c_str ()).length()));
+      wxString sep (pathP.Mid (Utf8ToLocal (nodePath.c_str ()).length(), 1));
+
       if ((!prefix.IsSameAs
           (Utf8ToLocal (nodePath.c_str()))) || !IsValidSeparator (sep))
        break;
@@ -729,8 +726,8 @@ public:
       if (!treeCtrl->IsExpanded (id))
         treeCtrl->Expand (id);
 
-      id = FindClosestChild (id, path);
-    } // while (id.IsOk ())
+      id = FindClosestChild (id, pathP);
+    } while (id.IsOk ());
 
     if (success)
       treeCtrl->SelectItem (id);
@@ -777,11 +774,9 @@ public:
         id = treeCtrl->GetNextChild (rootId, cookie);
       }
     }
-
     return success;
   }
 
-
   /**
    * Try to go up in the folder hierarchy until we
    * find a bookmark node.
@@ -811,7 +806,6 @@ public:
       // step up one level
       id = treeCtrl->GetItemParent (id);
     }
-
     return bookmarkId;
   }
 
@@ -831,7 +825,6 @@ public:
     return data->getPath ();
   }
 
- 
   Bookmark &
   GetSelectedBookmark ()
   {
@@ -851,7 +844,6 @@ public:
     return it->second;
   }
 
-
   void
   SetAuthPerBookmark (const bool perBookmark)
   {
@@ -893,7 +885,6 @@ public:
       it->second.ClearContext ();
   }
 
-
   void SetAuthCache (bool value)
   {
     useAuthCache = value;
@@ -909,14 +900,13 @@ public:
     for (; it!= bookmarks.end (); it++)
       it->second.SetAuthCache (value);
   }
-
 };
 
 BEGIN_EVENT_TABLE (FolderBrowser, wxControl)
   EVT_TREE_ITEM_EXPANDING (-1, FolderBrowser::OnExpandItem)
   EVT_TREE_ITEM_COLLAPSED (-1, FolderBrowser::OnCollapseItem)
+  EVT_TREE_KEY_DOWN (-1, FolderBrowser::OnTreeKeyDown)
   EVT_SIZE (FolderBrowser::OnSize)
-  EVT_TREE_ITEM_RIGHT_CLICK (-1, FolderBrowser::OnItemRightClk)
   EVT_CONTEXT_MENU (FolderBrowser::OnContextMenu)
 END_EVENT_TABLE ()
 
@@ -1009,6 +999,12 @@ FolderBrowser::OnSize (wxSizeEvent & WXUNUSED (event))
   }
 }
 
+void
+FolderBrowser::OnTreeKeyDown (wxTreeEvent & event)
+{
+  m->OnTreeKeyDown (event);
+}
+
 void
 FolderBrowser::OnExpandItem (wxTreeEvent & event)
 {
@@ -1021,29 +1017,6 @@ FolderBrowser::OnCollapseItem (wxTreeEvent & event)
   m->OnCollapseItem (event);
 }
 
-void
-FolderBrowser::OnItemRightClk (wxTreeEvent & event)
-{
-  RapidSvnFrame* frame = (RapidSvnFrame*) wxGetApp ().GetTopWindow ();
-  frame->SetActivePane (ACTIVEPANE_FOLDER_BROWSER);
-
-#ifdef __WXGTK__
-  // wxGTK doesn't seem to select an item upon right clicking - try doing it ourselves for now
-  wxPoint clientPt = event.GetPoint ();
-  const wxTreeItemId id = m->treeCtrl->HitTest (clientPt);
-  if (id.IsOk ())
-  {
-    m->treeCtrl->SelectItem (id);
-  }
-  // Show the menu now rather than waiting for OnContextMenu,
-  // and so don't Skip().
-  m->ShowMenu (clientPt);
-#else
-  // Let the OnContextMenu handler do the menu on MouseUp
-  event.Skip ();
-#endif
-}
-
 void
 FolderBrowser::OnContextMenu (wxContextMenuEvent & event)
 {
@@ -1081,7 +1054,6 @@ FolderBrowser::SelectBookmark (const wxString & bookmarkPath)
   return m->SelectBookmark (bookmarkPath);
 }
 
-
 void
 FolderBrowser::SetListener (svn::ContextListener * listener)
 {
@@ -1094,7 +1066,6 @@ FolderBrowser::GetListener () const
   return m->listener;
 }
 
-
 void
 FolderBrowser::WriteConfig (wxConfigBase * cfg) const
 {
@@ -1123,13 +1094,11 @@ FolderBrowser::WriteConfig (wxConfigBase * cfg) const
   }
 }
 
-
 void
 FolderBrowser::ReadConfig (wxConfigBase * cfg)
 {
   wxASSERT (cfg);
 
-
   long item, count;
   cfg->Read (ConfigBookmarkCount, &count, 0);
   for (item = 0; item < count; item++)
@@ -1149,7 +1118,6 @@ FolderBrowser::ReadConfig (wxConfigBase * cfg)
   }
 }
 
-
 const bool
 FolderBrowser::IsFlat () const
 {
@@ -1161,7 +1129,6 @@ FolderBrowser::IsFlat () const
   return bookmark.flatMode;
 }
 
-
 bool
 FolderBrowser::SetFlat (bool flatMode) 
 {
@@ -1174,7 +1141,6 @@ FolderBrowser::SetFlat (bool flatMode)
   return true;
 } 
   
-
 const bool
 FolderBrowser::GetAuthCache () const
 {
@@ -1206,4 +1172,3 @@ FolderBrowser::ExpandSelection ()
  * eval: (load-file "../rapidsvn-dev.el")
  * end:
  */
-
