@@ -32,6 +32,7 @@
 class wxImageList;
 class FolderItemData;
 class wxConfigBase;
+
 namespace svn
 {
   class Context;
@@ -46,7 +47,7 @@ public:
                  const wxSize & size = wxDefaultSize,
                  const wxString & name = wxT("FolderBrowser"));
 
-  virtual ~ FolderBrowser ();
+  virtual ~FolderBrowser ();
 
   virtual void 
   Refresh ();
@@ -146,7 +147,6 @@ public:
   const bool
   GetAuthPerBookmark () const;
 
-
   /**
    * check if authentication credentials should be cached or not
    */
@@ -162,11 +162,9 @@ public:
   void
   SetListener (svn::ContextListener * listener);
 
-
   svn::ContextListener *
   GetListener () const;
 
-
   /**
    * Writes configuration including bookmarks
    * to @a cfg
@@ -176,7 +174,6 @@ public:
   void
   WriteConfig (wxConfigBase * cfg) const;
 
-
   /**
    * Read configuration
    *
@@ -185,7 +182,6 @@ public:
   void
   ReadConfig (wxConfigBase * cfg);
 
-
   /**
    * Expand the selected leaf of the tree.
    * Has no effect if the selection has no
@@ -217,17 +213,12 @@ private:
   DECLARE_EVENT_TABLE ()
 
   void OnSize (wxSizeEvent & event);
-
+  void OnTreeKeyDown (wxTreeEvent & event);
   void OnExpandItem (wxTreeEvent & event);
-
   void OnCollapseItem (wxTreeEvent & event);
-
-  void OnItemRightClk (wxTreeEvent & event);
-
   void OnContextMenu (wxContextMenuEvent & event);
 };
 
-
 #endif
 /* -----------------------------------------------------------------
  * local variables:
