@@ -43,6 +43,9 @@ enum
   ID_HelpContents,
   ID_HelpIndex,
   ID_HelpStartupTips,
+  ID_TestNewWxString,
+  ID_TestListener,
+  ID_TestCheckout,
   ID_Preferences,
   ID_AddWcBookmark,
   ID_AddRepoBookmark,
@@ -62,8 +65,6 @@ enum
   ID_Checkout,
   ID_Cleanup,
   ID_Copy,
-  //ID_CopyTo,
-  ID_CopyHere,
   ID_Commit,
   ID_Default_Action,
   ID_Delete,
@@ -78,10 +79,8 @@ enum
   ID_Merge,
   ID_Mkdir,
   ID_Move,
-  //ID_MoveTo,
   ID_Property,
   ID_Rename,
-  //ID_RenameHere,
   ID_Resolve,
   ID_Revert,
   ID_Switch,
@@ -94,7 +93,11 @@ enum
   ID_Verb_Min,
   ID_Verb_Max = ID_Verb_Min + 16,
   ID_Column_Reset,
+  ID_Include_Path,
+  ID_Sort_Ascending,
   ID_Column_Min,
+  ID_Column_Name,
+  ID_Column_Path,
   ID_Column_Rev,
   ID_Column_Cmt_Rev,
   ID_Column_Author,
@@ -104,37 +107,77 @@ enum
   ID_Column_Extension,
   ID_Column_Text_Time,
   ID_Column_Prop_Time,
+  ID_Column_LockOwner,
+  ID_Column_LockComment,
+  ID_Column_Checksum,
   ID_Column_Url,
   ID_Column_Repos,
   ID_Column_Uuid,
-  //ID_Column_Kind, we dont need this, do we?
   ID_Column_Schedule,
   ID_Column_Copied, // combination of isCopied + copyfromUrl
   ID_Column_ConflictOld,
   ID_Column_ConflictNew,
   ID_Column_ConflictWrk,
-  ID_Column_LockOwner,
-  ID_Column_LockComment,
-  ID_Column_Checksum,
   ID_Column_Max,
 
+  /**
+   * ATTENTION!
+   *
+   * Don't forget to update ID_Column_* and ID_ColumnSort_*
+   * whenever changing one of them or making changes to
+   * the order of column in src/columns.cpp.
+   * This order should be the same in all 3 cases.
+   */
+  ID_ColumnSort_Min,
+  ID_ColumnSort_Name,
+  ID_ColumnSort_Path,
+  ID_ColumnSort_Rev,
+  ID_ColumnSort_Cmt_Rev,
+  ID_ColumnSort_Author,
+  ID_ColumnSort_Text_Status,
+  ID_ColumnSort_Prop_Status,
+  ID_ColumnSort_Cmt_Date,
+  ID_ColumnSort_Extension,
+  ID_ColumnSort_Text_Time,
+  ID_ColumnSort_Prop_Time,
+  ID_ColumnSort_LockOwner,
+  ID_ColumnSort_LockComment,
+  ID_ColumnSort_Checksum,
+  ID_ColumnSort_Url,
+  ID_ColumnSort_Repos,
+  ID_ColumnSort_Uuid,
+  ID_ColumnSort_Schedule,
+  ID_ColumnSort_Copied, // combination of isCopied + copyfromUrl
+  ID_ColumnSort_ConflictOld,
+  ID_ColumnSort_ConflictNew,
+  ID_ColumnSort_ConflictWrk,
+  ID_ColumnSort_Max,
+
   ACTION_EVENT, // this one gets sent from the action threads
-// Ids used for communication events between threads and frame
-  TOKEN_BASE,
+  // Ids used for communication events between threads and frame
   TOKEN_INFO,
+  TOKEN_ERROR,
   TOKEN_SVN_INTERNAL_ERROR,
   TOKEN_INTERNAL_ERROR,
   TOKEN_ACTION_START,
   TOKEN_ACTION_END,
+  TOKEN_CMD,
+  TOKEN_CMD_DIFF,
+  TOKEN_CMD_VIEW,
   TOKEN_DIFF,
   TOKEN_GET,
   TOKEN_VIEW,
   TOKEN_MERGE,
   TOKEN_ADD_BOOKMARK,
   TOKEN_DELETE_ACTION,
-  ACTION_UPDATE,
+  TOKEN_UPDATE_SORTING,
+  TOKEN_UPDATE_ASCENDING,
+
+  SIG_GET_LOG_MSG,
+  SIG_GET_LOGIN,
+
   FILELIST_CTRL,
-  FOLDER_BROWSER,
+  FOLDER_BROWSER
 };
 
 #endif
