@@ -1,9 +1,21 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2004 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
  *
- * This software is licensed as described in the file LICENSE.txt,
- * which you should have received as part of this distribution.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program (in the file GPL.txt); if not, write to 
+ * the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, 
+ * Boston, MA  02110-1301  USA
  *
  * This software consists of voluntary contributions made by many
  * individuals.  For exact contribution history, see the revision
@@ -16,6 +28,8 @@
 #include "wx/valgen.h"
 
 // app
+#include "hist_entries.hpp"
+#include "hist_val.hpp"
 #include "import_data.hpp"
 #include "import_dlg.hpp"
 #include "utils.hpp"
@@ -50,10 +64,12 @@ public:
     // Row 0:
     Grid->Add(new wxStaticText(wnd, -1, _("Repository URL")), 0,
               wxLEFT | wxALIGN_CENTER_VERTICAL, 5);
-    wxTextCtrl *Repository = new wxTextCtrl(wnd, -1, wxEmptyString,
-                                            wxDefaultPosition, wxSize(300, -1), 0,
-                                            wxTextValidator(wxFILTER_NONE, &data.Repository));
-    Grid->Add(Repository, 1, wxLEFT | wxEXPAND | wxALIGN_CENTER_VERTICAL, 5);
+
+    HistoryValidator val (HISTORY_REPOSITORY, &data.Repository);
+    wxComboBox *repository = 
+      new wxComboBox (wnd, -1, wxEmptyString, wxDefaultPosition,
+                      wxSize (235, -1), 0, 0, wxCB_DROPDOWN, val);
+    Grid->Add(repository, 1, wxLEFT | wxEXPAND | wxALIGN_CENTER_VERTICAL, 5);
 
     Grid->Add(new wxStaticText(wnd, -1, wxEmptyString), 0,
               0, 5);
@@ -144,9 +160,7 @@ ImportDlg::~ImportDlg ()
 void
 ImportDlg::OnOk (wxCommandEvent &event)
 {
-  wxString val;
-
-    // Transfer data from controls into m_data:
+  // Transfer data from controls into m_data:
   TransferDataFromWindow();
 
   TrimString (m->data.Repository);
