@@ -25,17 +25,21 @@
 
 // wxWidgets
 #include "wx/wx.h"
+#include "wx/thread.h"
 #include "wx/utils.h"
 
 // svncpp
 #include "svncpp/m_check.hpp"
 
 // app
-#include "listener.hpp"
-#include "cert_dlg.hpp"
-#include "tracer.hpp"
+#include "action_event.hpp"
 #include "auth_dlg.hpp"
+#include "cert_dlg.hpp"
 #include "commit_dlg.hpp"
+#include "config.hpp"
+#include "ids.hpp"
+#include "listener.hpp"
+#include "tracer.hpp"
 #include "utils.hpp"
 
 struct Listener::Data
@@ -54,21 +58,18 @@ public:
    */
   Tracer * tracer;
 
-
   /**
    * If ownTracer is TRUE, then this class
    * is responsible for deleting the tracer.
    */
   bool ownTracer;
 
-
   /**
    * is ongoing operation to be cancelled?
    * will be evaluated by Listener::contextCancel
    */
   bool isCancelled;
 
-
   /**
    * the context under which the action will be
    * performed. this includes auth info and callback
@@ -78,20 +79,61 @@ public:
 
   svn::Targets targets;
 
-  Data (wxWindow * parnt)
-    : parent (parnt), tracer (0), ownTracer (false),
-      isCancelled (false)
+  /**
+   * Mutex, condition and flag for protecting shared data
+   */
+  wxMutex mutex;
+  wxCondition * parentDoneSignal;
+  bool dataReceived;
+
+  /**
+   * Shared between two threads data
+   */
+  std::string message;
+  std::string username;
+  std::string password;
+  std::string certFile;
+
+  ContextListener::SslServerTrustAnswer sslAnswer;
+  ContextListener::SslServerTrustData sslData;
+  apr_uint32_t acceptedFailures;
+
+  Data (wxWindow * parent_)
+    : parent (parent_), tracer (NULL), ownTracer (false),
+      isCancelled (false), context (NULL), dataReceived (false)
   {
+    parentDoneSignal = new wxCondition (mutex);
   }
 
   virtual ~Data ()
   {
+    delete parentDoneSignal;
+
     if (tracer && ownTracer)
     {
       delete tracer;
     }
   }
 
+  void
+  SendEventToParent (int id) const
+  {
+    wxCommandEvent event (wxEVT_COMMAND_MENU_SELECTED, id);
+    wxPostEvent (parent, event);
+  }
+
+  void
+  WaitForParent () const
+  {
+    // Initial condition check, do not remove or recompose it.
+    // Necessary for the case if these lines are called AFTER sending a signal
+    // by parent. If not perform this check, signal is lost and we will wait
+    // for the parent eternally.
+    if (!dataReceived)
+    {
+      parentDoneSignal->Wait();
+    }
+  }
 };
 
 Listener::Listener (wxWindow * parent)
@@ -104,7 +146,6 @@ Listener::~Listener ()
   delete m;
 }
 
-
 void
 Listener::SetTracer (Tracer * t, bool own)
 {
@@ -131,14 +172,6 @@ Listener::Trace (const wxString & msg)
   {
     m->tracer->Trace (msg);
   }
-
-  wxSafeYield ();
-}
-
-void
-Listener::TraceError (const wxString & msg)
-{
-  Trace (msg);
 }
 
 void
@@ -147,7 +180,6 @@ Listener::SetParent (wxWindow * parent)
   m->parent = parent;
 }
 
-
 void
 Listener::SetContext (svn::Context * context)
 {
@@ -160,29 +192,6 @@ Listener::GetContext ()
   return m->context;
 }
 
-
-bool
-Listener::contextGetLogin (
-  const std::string & realm,
-  std::string & username,
-  std::string & password,
-  bool & maySave)
-{
-  // TODO: show realm
-  wxString LocalUsername (Utf8ToLocal (username));
-  wxString LocalPassword (Utf8ToLocal (password));
-  AuthDlg dlg (GetParent (), LocalUsername, LocalPassword);
-
-  bool ok = dlg.ShowModal () == wxID_OK;
-  if (ok)
-  {
-    LocalToUtf8 (dlg.GetUsername (), username);
-    LocalToUtf8 (dlg.GetPassword (), password);
-  }
-
-  return ok;
-}
-
 void
 Listener::contextNotify (const char *path,
                          svn_wc_notify_action_t action,
@@ -192,8 +201,6 @@ Listener::contextNotify (const char *path,
                          svn_wc_notify_state_t prop_state,
                          svn_revnum_t revision)
 {
-  //TODO: An exact copy lives in action.cpp which is not used, unlike here
-  // I suspect we should get rid of one, but I'm not sure which at the  moment...
   static const wxChar *
   ACTION_NAMES [] =
   {
@@ -223,46 +230,109 @@ Listener::contextNotify (const char *path,
     _("Failed to lock"),   // svn_wc_notify_failed_lock
     _("Failed to unlock")  // svn_wc_notify_failed_unlock
   };
-  
+
 #if CHECK_SVN_SUPPORTS_LOCK
-  const int MAX_ACTION = svn_wc_notify_failed_unlock;
+  static const int MAX_ACTION = svn_wc_notify_failed_unlock;
 #else
-  const int MAX_ACTION = svn_wc_notify_commit_postfix_txdelta;
+  static const int MAX_ACTION = svn_wc_notify_commit_postfix_txdelta;
 #endif
 
-  // Map an action to string and trace the action and path
-  const wxChar * actionString = 0;
-
-  if (action >= 0 && action <= MAX_ACTION)
-    actionString = ACTION_NAMES [action];
-
-  if (actionString != 0)
+  if (ACTION_NAMES[action] != NULL && action >= 0 && action <= MAX_ACTION)
   {
-    wxString msg, wxpath (Utf8ToLocal (path));
-    msg.Printf (wxT("%s: %s"), actionString, wxpath.c_str ());
+    static wxString msg;
+    msg.Printf (wxT("%s: %s"), ACTION_NAMES[action], Utf8ToLocal (path).c_str ());
 
     Trace (msg);
   }
 
-  // Implement code to generate usefule messages that can be
-  // transmitted with "Trace"
-  wxSafeYield ();
+#ifdef USE_SIMPLE_WORKER
+  static apr_time_t last_access = apr_time_now ();
+  if (apr_time_now () - last_access > 2000000)
+  {
+    last_access = apr_time_now ();
+    wxSafeYield ();
+  }
+#endif
 }
 
-
 bool
-Listener::contextGetLogMessage (std::string & msg)
+Listener::contextGetLogin (const std::string & realm,
+                           std::string & username,
+                           std::string & password,
+                           bool & maySave)
 {
-  CommitDlg dlg (GetParent (), true);
+  m->username = username;
+  m->password = password;
+
+  m->SendEventToParent (SIG_GET_LOGIN);
+  m->WaitForParent ();
+
+  // Parent has done its job and signalled. Performing main condition check.
+  bool success = m->dataReceived;
+  // Reset flag for next callbacks
+  m->dataReceived = false;
+
+  if (success)
+  {
+    username = m->username;
+    password = m->password;
+  }
+  return success;
+}
+
+void
+Listener::callbackGetLogin ()
+{
+  wxMutexLocker lock (m->mutex);
+
+  // TODO: show realm
+  wxString LocalUsername (Utf8ToLocal (m->username));
+  wxString LocalPassword (Utf8ToLocal (m->password));
+  AuthDlg dlg (GetParent (), LocalUsername, LocalPassword);
 
   bool ok = dlg.ShowModal () == wxID_OK;
   if (ok)
   {
-    LocalToUtf8 (dlg.GetMessage (), msg);
+    LocalToUtf8 (dlg.GetUsername (), m->username);
+    LocalToUtf8 (dlg.GetPassword (), m->password);
+    m->dataReceived = true;
   }
-  return ok;
+  m->parentDoneSignal->Broadcast ();
 }
 
+bool
+Listener::contextGetLogMessage (std::string & msg)
+{
+  m->message = msg;
+
+  m->SendEventToParent (SIG_GET_LOG_MSG);
+  m->WaitForParent ();
+
+  bool success = m->dataReceived;
+  m->dataReceived = false;
+
+  if (success)
+  {
+    msg = m->message;
+  }
+  return success;
+}
+
+void
+Listener::callbackGetLogMessage ()
+{
+  wxMutexLocker lock (m->mutex);
+  CommitDlg dlg (GetParent (), true);
+
+  bool ok = dlg.ShowModal () == wxID_OK;
+
+  if (ok)
+  {
+    LocalToUtf8 (dlg.GetMessage (), m->message);
+    m->dataReceived = true;
+  }
+  m->parentDoneSignal->Broadcast ();
+}
 
 svn::ContextListener::SslServerTrustAnswer
 Listener::contextSslServerTrustPrompt (
@@ -277,7 +347,6 @@ Listener::contextSslServerTrustPrompt (
   return dlg.Answer ();
 }
 
-
 bool
 Listener::contextSslClientCertPrompt (std::string & certFile)
 {
@@ -311,37 +380,24 @@ Listener::contextSslClientCertPwPrompt (std::string & password,
   return true;
 }
 
-
 bool
 Listener::contextCancel ()
 {
-  return false;
-
-// Commented out the following code, because
-// it caused a lot of flickering on Mac OS/X
-// in the menu bar and was really slow.
-//
-// On the other hand, until we have some real
-// threading this isnt of much use anyway 
-//  wxSafeYield ();
-//  return m->isCancelled;
+  return m->isCancelled;
 }
 
-
 bool
 Listener::isCancelled () const
 {
   return m->isCancelled;
 }
 
-
 void
 Listener::cancel (bool value)
 {
   m->isCancelled = value;
 }
 
-
 /* -----------------------------------------------------------------
  * local variables:
  * eval: (load-file "../rapidsvn-dev.el")
