@@ -36,12 +36,12 @@
 // forward declarations
 class Tracer;
 class wxWindow;
+
 namespace svn
 {
   class Context;
 }
 
-
 /**
  * Class that listens to the @a svn::ContextListener interface
  * and forwards information to the app and requests informations
@@ -57,19 +57,16 @@ public:
    */
   Listener (wxWindow * parent);
 
-
   /**
    * destructor
    */
   virtual ~Listener ();
 
-
   /**
    * @return Tracer instance
    */
   Tracer * GetTracer ();
 
-
   /**
    * Sets the tracer passed as an argument.
    * If own is TRUE, then the @a Listener class
@@ -77,7 +74,6 @@ public:
    */
   void SetTracer (Tracer * t, bool own);
 
-
   /**
    * set actions parent window
    *
@@ -85,13 +81,11 @@ public:
    */
   void SetParent (wxWindow * parent);
 
-
   /**
    * @return parent
    */
   wxWindow * GetParent ();
 
-
   /**
    * sets the context
    *
@@ -99,14 +93,12 @@ public:
    */
   void SetContext (svn::Context * context);
 
-
   /**
    * @return the context of the action
    */
   svn::Context *
   GetContext ();
 
-
   /**
    * @see svn::ContextListener
    */
@@ -114,7 +106,10 @@ public:
   contextGetLogin (const std::string & realm,
                    std::string & username,
                    std::string & password,
-				           bool & maySave);
+	           bool & maySave);
+
+  virtual void
+  callbackGetLogin ();
 
   /**
    * @see svn::ContextListener
@@ -134,6 +129,9 @@ public:
   virtual bool
   contextGetLogMessage (std::string & msg);
 
+  virtual void
+  callbackGetLogMessage ();
+
   /**
    * @see svn::ContextListener
    */
@@ -156,14 +154,12 @@ public:
                                 const std::string & realm,
                                 bool & maySave);
 
-
   /**
    * @see svn::ContextListener
    */
   virtual bool
   contextCancel ();
 
-
   /**
    * shall the ongoing operation be cancelled?
    *
@@ -176,7 +172,6 @@ public:
   void
   cancel (bool value);
 
-
   /**
    * @see cancel
    * @return check whether the ongoing operation is to be cancelled
@@ -189,11 +184,9 @@ public:
 protected:
   void Trace (const wxString & msg);
 
-  void TraceError (const wxString & msg);
-
 private:
+  // implementation specific data
   struct Data;
-  // this structure contains implementation specific data
   Data * m;
 
   /**
