@@ -29,14 +29,14 @@
 #include "wx/listctrl.h"
 
 // app
+#include "action_event.hpp"
 #include "diff_data.hpp"
 #include "get_data.hpp"
-#include "merge_dlg.hpp"
 #include "ids.hpp"
 #include "log_dlg.hpp"
+#include "merge_dlg.hpp"
 #include "utils.hpp"
 
-
 enum
 {
   ID_View = 1,
@@ -61,7 +61,6 @@ public:
     DeleteAllItems ();
   }
 
-
   /**
    * Returns the revision for the given @a item
    *
@@ -103,7 +102,6 @@ public:
     return GetRevisionForItem (item);
   }
 
-
   /**
    * returns the selected revisions.
    * Like @a GetSelectedRevision, but can return 
@@ -116,14 +114,12 @@ public:
   GetSelectedRevisions () const
   {
     RevnumArray array;
-
-    long item=-1;
+    long item = -1;
 
     do
     {
       item = GetNextItem (item, wxLIST_NEXT_ALL,
                                wxLIST_STATE_SELECTED);
-
       if (item != -1)
       {
         svn_revnum_t revnum (GetRevisionForItem (item));
@@ -136,9 +132,9 @@ public:
     return array;
   }
 
-
 private:
   void OnSelected (wxListEvent& event);
+
   void InitializeList (const svn::LogEntries * entries)
   {
     SetSingleStyle (wxLC_REPORT);
@@ -175,13 +171,12 @@ private:
       SetItem (index, 3, Utf8ToLocal (entry.message.c_str ()));
       index++;
     }
- 
   }
-  
 };
 
 struct LogDlg::Data
 {
+private:
   LogList * m_logList;
   wxTextCtrl * m_logMsg;
   wxButton * m_buttonView;
@@ -189,14 +184,12 @@ struct LogDlg::Data
   wxButton * m_buttonDiff;
   wxButton * m_buttonMerge;
 
-private:
 public:
   const svn::LogEntries * entries;
   wxString path;
   wxWindow * parent;
   wxWindow * window;
 
-
   Data (wxWindow * parent_,
         wxWindow * wnd,
         const char * path_,
@@ -271,17 +264,13 @@ public:
   void
   OnGet ()
   {
-    wxBusyCursor busy;
- 
     svn_revnum_t revnum = m_logList->GetSelectedRevision ();
- 
-    wxCommandEvent event = CreateActionEvent (TOKEN_GET);
+
     GetData * data = new GetData ();
     data->revision = revnum;
     data->path = path;
-    event.SetClientData (data);
 
-    wxPostEvent (parent, event);
+    ActionEvent::Post (parent, TOKEN_GET, data);
   }
 
   /**
@@ -290,17 +279,13 @@ public:
   void
   OnView ()
   {
-    wxBusyCursor busy;
- 
     svn_revnum_t revnum = m_logList->GetSelectedRevision ();
  
-    wxCommandEvent event = CreateActionEvent (TOKEN_VIEW);
     GetData * data = new GetData ();
     data->revision = revnum;
     data->path = path;
-    event.SetClientData (data);
 
-    wxPostEvent (parent, event);
+    ActionEvent::Post (parent, TOKEN_VIEW, data);
   }
     
   void
@@ -330,16 +315,12 @@ public:
       return;
     }
 
-    wxBusyCursor busy;
-
-    wxCommandEvent event (CreateActionEvent (TOKEN_DIFF));
     DiffData * data = new DiffData ();
     data->compareType = DiffData::TWO_REVISIONS;
     data->revision1 = svn::Revision (array[0]);
     data->revision2 = svn::Revision (array[1]);
-    event.SetClientData (data);
 
-    wxPostEvent (parent, event);
+    ActionEvent::Post (parent, TOKEN_DIFF, data);
   }
 
   void
@@ -354,9 +335,6 @@ public:
       return;
     }
 
-    wxBusyCursor busy;
-
-    wxCommandEvent event (CreateActionEvent (TOKEN_MERGE));
     MergeData * data = new MergeData ();
     data->Path1 = path;
     data->Path2 = path;
@@ -371,9 +349,7 @@ public:
       data->Path2Rev << array[1];
     }
 
-    event.SetClientData (data);
-
-    wxPostEvent (parent, event);
+    ActionEvent::Post (parent, TOKEN_MERGE, data);
   }
 
   void 
@@ -403,7 +379,6 @@ LogDlg::LogDlg (wxWindow * parent,
               wxDefaultSize, wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER)
 {
   m = new Data (parent, this, path, entries);
-
   CentreOnParent ();
 }
 
