@@ -34,28 +34,14 @@
 #include "destination_dlg.hpp"
 #include "utils.hpp"
 
-MoveAction::MoveAction (wxWindow * parent,
-                                int kind)
+MoveAction::MoveAction (wxWindow * parent, int kind)
  : Action (parent, wxEmptyString, GetBaseFlags ()),
    m_kind (kind)
 {
-  wxString name;
-  switch (kind)
-  {
-  case MOVE_MOVE:
-    name = _("Move");
-    break;
-  case MOVE_COPY:
-    name = _("Copy");
-    break;
-  case MOVE_RENAME:
-    name = _("Rename");
-    break;
-  default:
-    break;
-  }
-
-  SetName (name);
+  if (kind == MOVE_MOVE)
+    SetName (_("Move"));
+  else
+    SetName (_("Copy"));
 }
 
 bool
@@ -68,40 +54,16 @@ MoveAction::Prepare ()
 
   // create flags for the dialog
   int flags = 0;
-  switch (m_kind)
-  {
-  case MOVE_MOVE:
-  case MOVE_RENAME:
+
+  if (m_kind == MOVE_MOVE)
     flags = DestinationDlg::WITH_FORCE;
-    break;
-  case MOVE_COPY:
-    break;
-  default: // invalid kind
-    return false;
-  }
 
   // create description for the dialog
-  wxString descr;
-  switch (m_kind)
-  {
-  case MOVE_COPY:
-  case MOVE_MOVE:
-    descr = _("Select destination:");
-    break;
-  case MOVE_RENAME:
-    descr = _("Enter new name:");
-    break;
-  default:
-    return false;
-  }
-
   DestinationDlg dlg (GetParent (), GetName (),
-                      descr, flags);
+                      _("Select destination:"), flags);
 
   if (dlg.ShowModal () != wxID_OK)
-  {
     return false;
-  }
 
   m_destination = dlg.GetDestination ();
   m_force = dlg.GetForce ();
@@ -114,35 +76,26 @@ MoveAction::Perform ()
 {
   svn::Client client (GetContext ());
 
-  svn::Path srcPath = GetTarget ();
   svn::Path destPath (PathUtf8 (m_destination));
   svn::Revision unusedRevision;
+  std::vector<svn::Path> targets (GetTargets ().targets ());
+  std::vector<svn::Path>::iterator it;
 
-  switch (m_kind)
+  for (it = targets.begin (); it != targets.end (); it++)
   {
-  case MOVE_COPY:
-    client.copy (srcPath, unusedRevision, destPath);
-    break;
+    svn::Path srcPath (*it);
 
-  case MOVE_MOVE:
-    client.move (srcPath, unusedRevision, destPath, m_force);
-    break;
+    if (srcPath == GetPath ())
+      srcPath = ".";
 
-  case MOVE_RENAME:
-    {
-      std::string basename;
-      std::string dirpath;
-      srcPath.split (dirpath, basename);
-
-      svn::Path newDestPath (dirpath);
-      newDestPath.addComponent(destPath.c_str ());
-
-      client.move (srcPath, unusedRevision, newDestPath, m_force);
-    }
-    break;
+    if (m_kind == MOVE_MOVE)
+      client.move (srcPath, unusedRevision, destPath, m_force);
+    else
+      client.copy (srcPath, unusedRevision, destPath);
   }
   return true;
 }
+
 /* -----------------------------------------------------------------
  * local variables:
  * eval: (load-file "../rapidsvn-dev.el")
