@@ -48,12 +48,13 @@ typedef enum
 }
 ActivePane;
 
-
 // forward declarations
 class svn::Targets;
 class wxFrame;
+class wxMenu;
+class wxString;
 
-class RapidSvnFrame:public wxFrame
+class RapidSvnFrame : public wxFrame
 {
 public:
   /**
@@ -67,13 +68,15 @@ public:
   virtual ~RapidSvnFrame ();
 
   /** Allow children to trim their popup menus using the frames logic */
-  void TrimDisabledMenuItems (wxMenu & menu);
+  void
+  TrimDisabledMenuItems (wxMenu & menu);
 
   /**
   * Change the active window, if the corresponding event is handled
   * in one of the sub-windows
   */
-  void SetActivePane (ActivePane value);
+  void
+  SetActivePane (ActivePane value);
 
 private:
   /** disallow default constructor */
@@ -94,12 +97,15 @@ private:
   // View menu
   void OnPreferences (wxCommandEvent & event);
   void OnRefresh (wxCommandEvent & event);
+  void OnColumnReset (wxCommandEvent & event);
+  void OnColumn (wxCommandEvent & event);
+  void OnIncludePath (wxCommandEvent & event);
+  void OnSortAscending (wxCommandEvent & event);
+  void OnColumnSorting (wxCommandEvent & event);
+  void OnFlatView (wxCommandEvent & event);
   void OnRefreshWithUpdate (wxCommandEvent & event);
   void OnShowUnversioned (wxCommandEvent & event);
   void OnIgnoreExternals (wxCommandEvent & event);
-  void OnColumn (wxCommandEvent & event);
-  void OnColumnReset (wxCommandEvent & event);
-  void OnFlatView (wxCommandEvent & event);
   void OnStop (wxCommandEvent & event);
 
   // Query menu
@@ -113,15 +119,19 @@ private:
   void OnCleanup (wxCommandEvent & event);
 
   // Help menu
-  void OnHelp(wxCommandEvent & event);
   void OnHelpContents (wxCommandEvent & event);
   void OnHelpIndex (wxCommandEvent & event);
   void OnHelpStartupTips (wxCommandEvent & event);
   void OnAbout (wxCommandEvent & event);
 
+  // Test menu
+  void OnTestNewWxString (wxCommandEvent & event);
+  void OnTestListener (wxCommandEvent & event);
+  void OnTestCheckout (wxCommandEvent & event);
+  void PrintTimeMeasurements (apr_time_t start, apr_time_t end, const wxString & name);
+
   // toolbar events
   void OnToolEnter (wxCommandEvent & event);
-  void OnToolLeftClick (wxCommandEvent & event);
 
   // Events from action threads
   void OnActionEvent (wxCommandEvent & event);
@@ -137,7 +147,9 @@ private:
   void OnLogin (wxCommandEvent & event);
   void OnLogout (wxCommandEvent & event);
 
-  void UpdateCurrentPath ();
+  // Help listener to handle callbacks
+  void OnGetLogMessage (wxCommandEvent & event);
+  void OnGetLogin (wxCommandEvent & event);
 
   /**
    * Invoke the default action on the currently selected item(s)
@@ -155,13 +167,15 @@ private:
   /** update the contents of the folder browser */
   void UpdateFolderBrowser ();
 
-  // utility functions
-  void ShowLog ();
-  void ShowInfo ();
+  // Auxiliary functions
+  void UpdateCurrentPath ();
+  void UpdateMenuSorting ();
+  void UpdateMenuIncludePath ();
+  void UpdateMenuAscending ();
+  void SetIncludePathVisibility (bool flatMode);
 
   // Enable/disable action menu items
-  bool
-  RapidSvnFrame::ValidateIDActionFlags (int id, unsigned int selectionActionFlags);
+  bool ValidateIDActionFlags (int id, unsigned int selectionActionFlags);
   void OnUpdateCommand (wxUpdateUIEvent & updateUIEvent);
 
   const svn::Targets
@@ -174,6 +188,10 @@ private:
   unsigned int
   GetSelectionActionFlags () const;
 
+  // Utility functions
+  void ShowLog ();
+  void ShowInfo ();
+
   void DelEntries ();
   void MakeRevert ();
   void MakeResolve ();
@@ -192,30 +210,9 @@ private:
 
   void Perform (Action * action);
 
-  /**
-   * returns the visibility of a column in the filelist
-   *
-   * @param col column index
-   * @return visibility
-   * @retval true=visible
-   */
-  const int
-  GetColumnVisible (const int col) const;
-
-  /**
-   * sets the visibility of a column in the filelist
-   * the column menu entry is checked/unchecked as well
-   *
-   * @param col column index
-   * @param visible true=visible
-   */
-  void
-  SetColumnVisible (const int col, const bool visible);
-
 private:
-  struct Data;
-
   /** hide implementation data */
+  struct Data;
   Data * m;
 
   ActionWorker * m_actionWorker;
@@ -241,10 +238,18 @@ private:
   /**
    * add message to log window
    *
-   * @param msg message to add
+   * @param msg message to show
    */
   void
-  Trace (wxString msg) ;
+  Trace (const wxString & msg) ;
+
+  /**
+   * add error message to log window marked red
+   *
+   * @param msg error message to show
+   */
+  void
+  TraceError (const wxString & msg) ;
 
 private:
   DECLARE_EVENT_TABLE ()
