@@ -1,9 +1,21 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2004 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
  *
- * This software is licensed as described in the file LICENSE.txt,
- * which you should have received as part of this distribution.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ * 
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ * 
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library (in the file LGPL.txt); if not, 
+ * write to the Free Software Foundation, Inc., 51 Franklin St, 
+ * Fifth Floor, Boston, MA  02110-1301  USA
  *
  * This software consists of voluntary contributions made by many
  * individuals.  For exact contribution history, see the revision
@@ -30,9 +42,11 @@
 
 namespace svn
 {
+#if CHECK_SVN_SUPPORTS_PEG
   std::string
   Client::cat (const Path & path, 
-               const Revision & revision) throw (ClientException)
+               const Revision & revision,
+               const Revision & peg_revision) throw (ClientException)
   {
     Pool pool;
     
@@ -40,7 +54,32 @@ namespace svn
     svn_stream_t * stream = svn_stream_from_stringbuf (stringbuf, pool);
 
     svn_error_t * error;
-    error = svn_client_cat (stream, path.c_str (),
+    error = svn_client_cat2 (stream,
+                             path.c_str (),
+                             peg_revision.revision (),
+                             revision.revision (), 
+                             *m_context, 
+                             pool);
+
+    if (error != 0)
+      throw ClientException (error);
+
+    return std::string (stringbuf->data, stringbuf->len);
+  }
+#else
+  std::string
+  Client::cat (const Path & path, 
+               const Revision & revision,
+               const Revision & peg_revision) throw (ClientException)
+  {
+    Pool pool;
+    
+    svn_stringbuf_t * stringbuf = svn_stringbuf_create ("", pool);
+    svn_stream_t * stream = svn_stream_from_stringbuf (stringbuf, pool);
+
+    svn_error_t * error;
+    error = svn_client_cat (stream,
+                            path.c_str (),
                             revision.revision (), 
                             *m_context, 
                             pool);
@@ -48,9 +87,9 @@ namespace svn
     if (error != 0)
       throw ClientException (error);
 
-    return std::string( stringbuf->data, stringbuf->len );
+    return std::string (stringbuf->data, stringbuf->len);
   }
-
+#endif
 
   /**
    * Create a new temporary file in @a dstPath. If @a dstPath
@@ -122,7 +161,6 @@ namespace svn
     return file;
   }
 
-
   void
   Client::get (Path & dstPath,
                const Path & path,
