@@ -1,9 +1,21 @@
 /*
  * ====================================================================
- * Copyright (c) 2002-2004 The RapidSvn Group.  All rights reserved.
+ * Copyright (c) 2002-2006 The RapidSvn Group.  All rights reserved.
  *
- * This software is licensed as described in the file LICENSE.txt,
- * which you should have received as part of this distribution.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ * 
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ * 
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library (in the file LGPL.txt); if not, 
+ * write to the Free Software Foundation, Inc., 51 Franklin St, 
+ * Fifth Floor, Boston, MA  02110-1301  USA
  *
  * This software consists of voluntary contributions made by many
  * individuals.  For exact contribution history, see the revision
@@ -27,7 +39,8 @@
 #include "svncpp/status.hpp"
 #include "svncpp/targets.hpp"
 #include "svncpp/url.hpp"
-
+#include "m_svn_status.hpp"
+#include "m_converter.hpp"
 
 namespace svn
 {
@@ -40,9 +53,9 @@ namespace svn
                    const char *msg, 
                    apr_pool_t * pool)
   {
-    LogEntries * entries = 
-      (LogEntries *) baton;
+    LogEntries * entries = (LogEntries *) baton;
     entries->insert (entries->begin (), LogEntry (rev, author, date, msg));
+
     if (changedPaths != NULL)
     {
       LogEntry &entry = entries->front ();
@@ -62,28 +75,20 @@ namespace svn
                                   log_item->action,
                                   log_item->copyfrom_path,
                                   log_item->copyfrom_rev) );
-
       }
     }
 
     return NULL;
   }
 
-  struct StatusEntriesBaton {
-    apr_pool_t* pool;
-    apr_hash_t* hash;
-  };
-
   static void StatusEntriesFunc (void *baton,
                                  const char *path,
-                                 svn_wc_status_t *status)
+                                 svn::SvnStatus *status)
   {
-      svn_wc_status_t* stat;
-      StatusEntriesBaton* seb = (StatusEntriesBaton*)baton;
+    StatusEntries * entries = static_cast<StatusEntries *>(baton);
 
-      path = apr_pstrdup (seb->pool, path);
-      stat = svn_wc_dup_status (status, seb->pool);
-      apr_hash_set (seb->hash, path, APR_HASH_KEY_STRING, stat);
+    static Converter converter;
+    entries->push_back (converter.toStatus (path, status));
   }
 
   static StatusEntries
@@ -92,58 +97,47 @@ namespace svn
                const bool get_all,
                const bool update,
                const bool no_ignore,
-               Context * context)
+               Context * context,
+               const bool ignore_externals)
   {
     svn_error_t *error;
     StatusEntries entries;
-    apr_hash_t *status_hash;
     svn_revnum_t revnum;
     Revision rev (Revision::HEAD);
     Pool pool;
-    StatusEntriesBaton baton;
 
-    status_hash = apr_hash_make (pool);
-    baton.hash = status_hash;
-    baton.pool = pool;
-
-    error = svn_client_status (
-      &revnum,      // revnum
-      path,         // path
-      rev,
+#if (CHECK_SVN_VERSION(1,2))
+    error = svn_client_status2 (
+      &revnum,    // revnum
+      path,       // path
+      rev,        // revision
       StatusEntriesFunc, // status func
-      &baton,        // status baton
-      descend,
+      &entries,   // status baton
+      descend,    // recurse
+      get_all,
+      update,     // need 'update' to be true to get repository lock info
+      no_ignore,
+      ignore_externals, // ignore_externals
+      *context,   // client ctx
+      pool);
+#else
+    error = svn_client_status (
+      &revnum,    // revnum
+      path,       // path
+      rev,        // revision
+      StatusEntriesFunc, // status func
+      &entries,   // status baton
+      descend,    // recurse
       get_all,
       update,
       no_ignore,
-      *context,    //client ctx
+      *context,   //client ctx
       pool);
+#endif
 
     if (error!=NULL)
-    {
       throw ClientException (error);
-    }
 
-    apr_array_header_t *statusarray = 
-      svn_sort__hash (status_hash, svn_sort_compare_items_as_paths,
-                            pool);
-    int i;
-
-    /* Loop over array, printing each name/status-structure */
-    for (i = statusarray->nelts-1; i >= 0; i--)
-    {
-      const svn_sort__item_t *item;
-      const char *filePath;
-      svn_wc_status_t *status = NULL;
-
-      item = &APR_ARRAY_IDX (statusarray, i, const svn_sort__item_t);
-      status = (svn_wc_status_t *) item->value;
-
-      filePath = (const char *) item->key;
-
-      entries.push_back (Status (filePath, status));
-    }
-    
     return entries;
   }
   
@@ -171,9 +165,9 @@ namespace svn
     e->cmt_date = dirEntry.time ();
     e->cmt_author = dirEntry.lastAuthor ();
 
-    svn_wc_status_t * s =
-      static_cast<svn_wc_status_t *> (
-        apr_pcalloc (pool, sizeof (svn_wc_status_t)));
+    svn::SvnStatus * s =
+      static_cast<svn::SvnStatus *> (
+        apr_pcalloc (pool, sizeof (svn::SvnStatus)));
     s->entry = e;
     s->text_status = svn_wc_status_normal;
     s->prop_status = svn_wc_status_normal;
@@ -182,7 +176,8 @@ namespace svn
     s->repos_text_status = svn_wc_status_normal;
     s->repos_prop_status = svn_wc_status_normal;
 
-    return Status (url.c_str (), s);
+    static Converter converter;
+    return converter.toStatus (url.c_str (), s);
   }
 
   static StatusEntries
@@ -215,60 +210,59 @@ namespace svn
                   const bool descend,
                   const bool get_all,
                   const bool update,
-                  const bool no_ignore) throw (ClientException)
+                  const bool no_ignore,
+                  const bool ignore_externals) throw (ClientException)
   {
     if (Url::isValid (path))
       return remoteStatus (this, path, descend, get_all, update, 
                            no_ignore, m_context);
     else
       return localStatus (path, descend, get_all, update, 
-                          no_ignore, m_context);
+                          no_ignore, m_context, ignore_externals);
   }
   
   static Status
   localSingleStatus (const char * path, Context * context)
   {
     svn_error_t *error;
-    apr_hash_t *status_hash;
+    StatusEntries entries;
     Pool pool;
-    StatusEntriesBaton baton;
     svn_revnum_t revnum;
     Revision rev (Revision::HEAD);
 
-    status_hash = apr_hash_make( pool );
-    baton.hash = status_hash;
-    baton.pool = pool;
-
-    error = svn_client_status (
-      &revnum,      // revnum
-      path,         // path
-      rev,
+#if (CHECK_SVN_VERSION(1,2))
+    error = svn_client_status2 (
+      &revnum,   // revnum
+      path,      // path
+      rev,       // revision
       StatusEntriesFunc, // status func
-      &baton,        // status baton
-      false,
-      true,
-      false,
-      false,
-      *context,    //client ctx
+      &entries,  // status baton
+      false,     // recurse
+      true,      // get_all
+      false,     // update
+      false,     // no_ignore
+      true,      // ignore_externals
+      *context,  // client ctx
       pool);
+#else
+    error = svn_client_status (
+      &revnum,   // revnum
+      path,      // path
+      rev,       // revision
+      StatusEntriesFunc, // status func
+      &entries,  // status baton
+      false,     // recurse
+      true,      // get_all
+      false,     // update
+      false,     // no_ignore
+      *context,  // client ctx
+      pool);
+#endif
 
     if (error != NULL)
-    {
       throw ClientException (error);
-    }
-    
-    apr_array_header_t *statusarray = 
-      svn_sort__hash (status_hash, svn_sort_compare_items_as_paths,
-                            pool);
-    const svn_sort__item_t *item;
-    const char *filePath;
-    svn_wc_status_t *status = NULL;
 
-    item = &APR_ARRAY_IDX (statusarray, 0, const svn_sort__item_t);
-    status = (svn_wc_status_t *) item->value;
-    filePath = (const char *) item->key;
-    
-    return Status (filePath, status);
+    return entries[0];
   };
 
   static Status
@@ -293,15 +287,49 @@ namespace svn
       return localSingleStatus (path, m_context);
   }
 
+#if CHECK_SVN_SUPPORTS_PEG
   const LogEntries *
   Client::log (const char * path, const Revision & revisionStart, 
                const Revision & revisionEnd, bool discoverChangedPaths,
                bool strictNodeHistory ) throw (ClientException)
   {
-    Targets target (path);
     Pool pool;
+    Targets target (path);
     LogEntries * entries = new LogEntries ();
     svn_error_t *error;
+    int limit = 0;
+
+    error = svn_client_log2 (
+      target.array (pool), 
+      revisionStart.revision (), 
+      revisionEnd.revision (), 
+      limit,
+      discoverChangedPaths ? 1 : 0,
+      strictNodeHistory ? 1 : 0,
+      logReceiver,
+      entries, 
+      *m_context, // client ctx
+      pool);
+
+    if (error != NULL)
+    {
+      delete entries;
+      throw ClientException (error);
+    }
+
+    return entries;
+  }
+#else
+  const LogEntries *
+  Client::log (const char * path, const Revision & revisionStart, 
+               const Revision & revisionEnd, bool discoverChangedPaths,
+               bool strictNodeHistory ) throw (ClientException)
+  {
+    Pool pool;
+    Targets target (path);
+    LogEntries * entries = new LogEntries ();
+    svn_error_t *error;
+
     error = svn_client_log (
       target.array (pool), 
       revisionStart.revision (), 
@@ -321,28 +349,29 @@ namespace svn
 
     return entries;
   }
+#endif
 
   Entry
-  Client::info (const char *path )
+  Client::info (const char * path)
   {
     Pool pool;
-    svn_wc_adm_access_t *adm_access;
+    svn_wc_adm_access_t * adm_access;
 
-    svn_error_t *error
-      = svn_wc_adm_probe_open (&adm_access, NULL, path, FALSE,
-                                    FALSE, pool);
+    svn_error_t * error =
+      svn_wc_adm_probe_open (&adm_access, NULL, path, FALSE,
+                             FALSE, pool);
     if (error != NULL)
       throw ClientException (error);
 
-    const svn_wc_entry_t *entry;
+    const svn_wc_entry_t * entry;
     error = svn_wc_entry (&entry, path, adm_access, FALSE, pool);
+
     if (error != NULL)
       throw ClientException (error);
 
     // entry may be NULL
     return Entry( entry );
   }
-
 }
 
 /* -----------------------------------------------------------------
