@@ -34,7 +34,6 @@
 #include "svncpp/pool.hpp"
 #include "svncpp/url.hpp"
 
-
 namespace svn
 {
   Path::Path (const char * path)
@@ -99,6 +98,15 @@ namespace svn
     return *this;
   }
 
+  bool
+  Path::operator== (const Path& path) const
+  {
+    if (path.path () == this->path ())
+      return true;
+
+    return false;
+  }
+
   bool
   Path::isset () const
   {
@@ -136,14 +144,12 @@ namespace svn
     }
   }
 
-
   void 
   Path::addComponent (const std::string & component)
   {
     addComponent (component.c_str ());
   }
 
-
   void
   Path::split (std::string & dirpath, std::string & basename) const
   {
@@ -158,7 +164,6 @@ namespace svn
     basename = cbasename;
   }
 
-
   void
   Path::split (std::string & dir, std::string & filename, std::string & ext) const
   {
@@ -181,6 +186,43 @@ namespace svn
     }
   }
 
+  std::string
+  Path::basename () const
+  {
+    std::string dir;
+    std::string filename;
+
+    split (dir, filename);
+
+    return filename;
+  }
+
+  std::string
+  Path::dirpath () const
+  {
+    std::string dir;
+    std::string filename;
+
+    split (dir, filename);
+
+    return dir;
+  }
+
+  std::string
+  Path::substr (const size_t count) const
+  {
+    if (m_path.length () > count)
+      return m_path.substr (count);
+    else
+      return "";
+  }
+
+  std::string
+  Path::unescape () const
+  {
+    return svn::Url::unescape (m_path.c_str ());
+  }
+
   /* ===================================================================
    * The next two Fixed_* functions are copies of the APR
    * apr_temp_dir_get functionality with a fix applied.
@@ -275,7 +317,6 @@ end:
     }
     return APR_EGENERAL;
   }
-
   /* ===================================================================
    * End of inserted fixed APR code
    */
@@ -294,14 +335,12 @@ end:
     return tempdir;
   }
 
-
   size_t 
   Path::length () const
   {
     return m_path.length ();
   }
 
-
   std::string
   Path::native () const
   {
@@ -309,7 +348,6 @@ end:
 
     return svn_path_local_style (m_path.c_str (), pool);
   }
-
 }
 
 /* -----------------------------------------------------------------
