@@ -224,15 +224,6 @@ CheckRevision (const wxString & revstring)
   return ParseRevision (revstring, revnum);
 }
 
-wxCommandEvent
-CreateActionEvent (int token)
-{
-  wxCommandEvent event (wxEVT_COMMAND_MENU_SELECTED, ACTION_EVENT);
-  event.SetInt (token);
-
-  return event;
-}
-
 wxMenuItem *
 AppendMenuItem (wxMenu & menu, int id)
 {
@@ -501,7 +492,6 @@ Utf8ToLocal (const char* srcUtf8)
   return dst;
 }
 
-
 wxFileName
 Utf8ToFileName (const char * srcUtf8)
 {
@@ -514,7 +504,6 @@ Utf8ToFileName (const char * srcUtf8)
   return dst;
 }
 
-
 wxString
 Utf8ToLocal (const std::string& srcUtf8)
 {
