@@ -47,7 +47,6 @@ namespace svn
   class Path;
 }
 
-
 /**
  * declaration of an array with @a svn_revnum_t elements
  */
@@ -140,13 +139,6 @@ AppendVerbMenu (wxMenu * parentMenu, svn::Status * status);
 bool
 CheckRevision (const wxString & revstring);
 
-/**
- * Creates an action event with @a token.
- *
- * @param token 
- */
-wxCommandEvent 
-CreateActionEvent (int token);
 
 /**
  * Creates a menu item for @a id (with whistles and bells, uh,
